import type { AxiosRequestConfig } from 'axios';
export type DeviceInfo = {
    brand: string;
    model: string;
    os_version?: string;
};
export type SDKInfo = {
    version: string;
    framework: 'ReactNative';
};
export type Status = 'Success' | 'Failure';
export type Event = 'extract' | 'send' | 'clear' | 'enqueue' | 'other';
export type ExtractionLog = {
    data_type: string;
    data_datetime: string;
    status: Status;
    event: Event;
    failure_reason?: string;
};
export type TransmissionLog = {
    data_type: string;
    data_datetime: string;
    server_response: string;
    event: Event;
    response_time?: string;
};
export type EventLog = {
    event: Event;
    [key: string]: string;
};
export type LoggerContext = {
    content: ExtractionLog | TransmissionLog | EventLog | null;
    deviceInfo: DeviceInfo | null;
    timestamp: string;
    configuration: LogConfig;
} & InitLogger;
export type LogConfig = {
    index: string;
    axiosConfig?: AxiosRequestConfig;
};
export type InitLogger = {
    clientUUID: string;
    configuration?: LogConfig;
    environment: 'development' | 'production' | 'sandbox';
    sdkInfo: SDKInfo | null;
    userID?: string;
};
export type LoggerEvent = {
    type: 'send';
    payload: ExtractionLog | TransmissionLog | EventLog;
} | {
    type: 'init';
    payload: InitLogger;
};
//# sourceMappingURL=LoggerTypes.d.ts.map